module Grants
  class InstitutionDocument
    def self.grants
      {
          create: {
              name: 'Hochladen',
              scopes: {
                  system_wide: {
                      name: 'Systemweit',
                      detailed_description: '
                        Dokumente können in jeder Einrichtung hinterlegt werden.
                      ',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :create, ::InstitutionDocument
                        ability.can :create_institution_document, ::Institution
                      end
                  },
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      detailed_description: 'Dokumente können in eigenen Einrichtungen hochgeladen werden',
                      user_types: [::Manager, ::Teacher],
                      default_for: [::Manager, ::Teacher],
                      manager: -> ability,manager do
                        ability.can :create, ::InstitutionDocument, {
                            institution: {
                                all_parent_institutions: {parent_id: manager.institution_id}
                            }
                        }
                        ability.can :create_institution_document, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id}
                        }
                      end,
                      teacher: -> ability,teacher do
                        ability.can :create, ::InstitutionDocument, {
                            institution: {
                                teacher_institution_relations: {
                                    teacher_id: teacher.id
                                }
                            }
                        }
                        ability.can :create_institution_document, ::Institution, {
                            teacher_institution_relations: {
                                teacher_id: teacher.id
                            }
                        }
                      end
                  },
              }
          },
          read: {
              name: 'Runterladen',
              scopes: {
                  system_wide: {
                      name: 'Systemweit',
                      detailed_description: 'Dokumente Systemweit anzeigen',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :read, ::InstitutionDocument
                        ability.can :read_institution_documents, ::Institution
                      end
                  },
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      detailed_description: 'Dokumente in eigenen Einrichtungen anzeigen',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability,manager do
                        ability.can :read, ::InstitutionDocument, {
                            institution: {
                                all_parent_institutions: {parent_id: manager.institution_id}
                            }
                        }
                        ability.can :read_institution_documents, ::Institution, {
                            all_parent_institutions: {parent_id: manager.institution_id}
                        }
                      end,
                      teacher: -> ability,teacher do
                        ability.can :read, ::InstitutionDocument, {
                            institution: {
                                teacher_institution_relations: {
                                    teacher_id: teacher.id
                                }
                            }
                        }
                        ability.can :read_institution_documents, ::Institution, {
                            teacher_institution_relations: {
                                teacher_id: teacher.id
                            }
                        }
                      end
                  }
              }
          },
          update: {
              name: 'Bearbeiten',
              scopes: {
                  system_wide: {
                      name: 'Systemweit',
                      detailed_description: 'Dokumente Systemweit bearbeiten',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :update, ::InstitutionDocument
                      end
                  },
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      detailed_description: 'Dokumente in eigenen Einrichtungen anzeigen',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability,manager do
                        ability.can :update, ::InstitutionDocument, {
                            institution: {
                                all_parent_institutions: {parent_id: manager.institution_id}
                            }
                        }
                      end,
                      teacher: -> ability,teacher do
                        ability.can :update, ::InstitutionDocument, {
                            institution: {
                                teacher_institution_relations: {
                                    teacher_id: teacher.id
                                }
                            }
                        }
                      end
                  },
              }
          },
          destroy: {
              name: 'Löschen',
              scopes: {
                  system_wide: {
                      name: 'Systemweit',
                      detailed_description: 'Dokumente systemweit löschen',
                      user_types: [::Manager],
                      default_for: [],
                      manager: -> ability do
                        ability.can :destroy, ::InstitutionDocument
                      end
                  },
                  own_institutions: {
                      name: 'in eigenen Einrichtungen',
                      detailed_description: 'Dokumente in eigenen Einrichtungen löschen',
                      user_types: [::Manager,::Teacher],
                      default_for: [::Manager,::Teacher],
                      manager: -> ability,manager do
                        ability.can :destroy, ::InstitutionDocument, {
                            institution: {
                                all_parent_institutions: {parent_id: manager.institution_id}
                            }
                        }
                      end,
                      teacher: -> ability,teacher do
                        ability.can :destroy, ::InstitutionDocument, {
                            institution: {
                                teacher_institution_relations: {
                                    teacher_id: teacher.id
                                }
                            }
                        }
                      end
                  }
              }
          }

      }
      end
  end
end