class AdvancementPlanBorrowsController < ApplicationController
  protect_from_forgery :except => [:update]


  def index
    respond_to do |format|
      format.html do
        if params[:teacher_id]
          @teacher = Teacher.accessible_by(current_ability).where(id: params[:teacher_id]).take!
          @advancement_plan_borrows_grid = AdvancementPlanBorrowsGrid.new(params[:advancement_plan_borrows_grid]) do |scope|
            scope.accessible_by(current_ability).where(teacher_id: params[:teacher_id]).page(params[:page]).per(5)
          end
          add_breadcrumb "Förderpläne", :advancement_plans_path
          add_breadcrumb "Ausgeliehenes von #{@teacher.first_name} #{@teacher.last_name}"
          render :index and return
        end
        if params[:institution_id]
          @institution = Institution.where(id: params[:institution_id]).take!
          authorize!(:create,AdvancementPlanBorrow)
          @advancement_plan = AdvancementPlan.where(catalog_id: params[:advancement_plan_catalog_id]).take!
          if current_user.is_teacher?
            @teacher = current_user.person
            @advancement_plan_borrow_new = AdvancementPlanBorrow.new(institution_id: params[:institution_id],advancement_plan_id:@advancement_plan.id,teacher_id: @teacher.id)
          else
            flash[:warning] = "Ausleihe ist nur für Lehrpersonen möglich"
            redirect_to :back and return
          end
          add_breadcrumb "Förderpläne", :advancement_plans_path
          add_breadcrumb "Ausleihe in #{@institution.name}"
          render :calendar and return
        end
      end
      format.json do
        @advancement_plan = AdvancementPlan.where(catalog_id: params[:advancement_plan_catalog_id]).take!
        @advancement_plan_borrows = @advancement_plan.advancement_plan_borrows.accessible_by(current_ability).only_not_returned.where(:institution_id => params[:institution_id]).where('from_date > ? and to_date < ?',params[:start], params[:end])
      end
    end
  end


  def edit
    @advancement_plan_borrow = AdvancementPlanBorrow.where(id: params[:id]).take!
    authorize!(:update, @advancement_plan_borrow)
    @advancement_plan_borrow.do_return = true
    render layout: false
  end

  def create
    @advancement_plan = AdvancementPlan.where(catalog_id: params[:advancement_plan_catalog_id]).take!
    @advancement_plan_borrow = AdvancementPlanBorrow.new(advancement_plan_borrow_create_params)
    @advancement_plan_borrow.advancement_plan_id = @advancement_plan.id
    authorize!(:create, @advancement_plan_borrow)
    @advancement_plan_borrow.save
    respond_to do |format|
      format.js{}
    end
  end

  def update
    @advancement_plan_borrow = AdvancementPlanBorrow.where(id: params[:id]).take!
    @advancement_plan_borrow.assign_attributes(advancement_plan_borrow_update_params)
    authorize!(:update, @advancement_plan_borrow)
    @advancement_plan_borrow.save
    respond_to do |format|
      format.js{}
      format.html{ redirect_to :back, success: "Rückgabe erfolgreich"}
    end
  end

  private
  def advancement_plan_borrow_create_params
    params.require(:advancement_plan_borrow).permit(
        :teacher_id, :institution_id, :from_date, :to_date
    )
  end

  def advancement_plan_borrow_update_params
    params.require(:advancement_plan_borrow).permit(
        :do_return
    )
  end



end
