class ApplicationController < ActionController::Base

  rescue_from CanCan::AccessDenied do |exception|
    respond_to do |format|
      if request.xhr?
        # respond to Ajax request
        format.json { head :forbidden }
        format.html { render text: exception.message }
      else
        # respond to normal request
        format.json { head :forbidden }
        format.html {
          if request.path == root_path
            render text: "#{exception.message}"
          else
            redirect_to root_url, :alert => exception.message
          end
        }
      end
    end
  end

  rescue_from JsonApiClient::Errors::ApiError do |exception|
    respond_to do |format|
      if request.xhr?
        # respond to Ajax request
        format.json { head :service_unavailable }
        format.html { render text: "Csb Service unavailable: #{exception.message}" }
      else
        # respond to normal request
        format.json { head :service_unavailable }
        format.html {
          if request.path == root_path
            render text: "Csb Service unavailable: #{exception.message}"
          else
            redirect_to root_url, :danger => "Csb Service unavailable: #{exception.message}"
          end
        }
      end
    end
  end

  # Prevent CSRF attacks by raising an exception.
  # For APIs, you may want to use :null_session instead.
  protect_from_forgery with: :exception

  before_action :authenticate_user!
  before_action :chained_form_elements



  layout :layout_by_resource

  add_breadcrumb "Dashboard", :user_dashboard_path

  add_flash_types :success, :warning, :danger, :info

  def layout_by_resource
    case
      when devise_controller?
        if controller_name == 'registrations' && ['edit','update'].include?(action_name)
          return 'application'
        else
          return false
        end
      else
        return "application"
    end

  end


  private

  def chained_form_elements
    if params['chained_form_element']
      unless respond_to?(params['chained_form_element'])
        cannot_find_method_alert = "<script type='text/javascript'>alert('Cannot call #{self.class}:#{params['chained_form_element']} to render dependent element. Implement the method and provide the view partial _#{params['chained_form_element']}.html.erb')</script>";
        render text: cannot_find_method_alert and return
      end
      do_render = send(params['chained_form_element'])
      unless do_render === false
        render :partial => params['chained_form_element'], :locals => { :disabled => false } and return
      else
        render status: :not_found and return
      end
    end
  end

  def after_sign_in_path_for(resource)
    user_dashboard_path
  end

  def after_sign_out_path_for(resource_or_scope)
    '/users/sign_in'
  end

  def redirect_to_404_if_not_super_admin
    unless current_user.super_admin?
      return render :file => "#{Rails.root}/public/404.html",  :status => 404
    end
    flash.now[:warning] = "Diese Aktion/Seite ist nur für super_admins aufrufbar!"
  end

  def redirect_to_404_if_not_admin
    unless current_user.super_admin?
      return render :file => "#{Rails.root}/public/404.html",  :status => 404
    end
    flash.now[:info] = "Diese Aktion/Seite sollte nur für administrative Benutzer aufrufbar sein."
  end

end
