class CareerItemsInstitutionController < ApplicationController

  before_action :set_client, only: [:index, :new, :create]

  def index
    add_breadcrumb "SchülerInnen", :clients_path, title: "alle SchülerInnen anzeigen"
    add_breadcrumb "#{view_context.show_person(@client)}", dashboard_client_path(@client), title: "Übersicht anzeigen"
    add_breadcrumb "Laufbahn", client_career_items_path(@client), title: "gesamte Laufbahn anzeigen"
    add_breadcrumb "#{CareerItem::CHANGE_TYPES[3]}"

    @career_items_grid = CareerItemsInstitutionGrid.new(params[:career_items_institution_grid]) do |scope|
      scope.where(client_id: params[:client_id]).page(params[:page]).per(25)
    end
  end

  def new
    authorize!(:update, @client) # a new career item does in fact change the client
    add_breadcrumb "SchülerInnen", :clients_path, title: "alle SchülerInnen anzeigen"
    add_breadcrumb "#{view_context.show_person(@client)}", dashboard_client_path(@client), title: "Übersicht anzeigen"
    add_breadcrumb "#{CareerItem::CHANGE_TYPES[3]}"

    @career_item = @client.career_items.build({change_type: CareerItem::CHANGE_TYPE_INSTITUTION})


    # die im Dropdown verfügbaren Einrichtungen
    @available_institutions = {}

    # alle an der aktuellen OE verfügbaren pädagogischen Einrichtungen
    # gruppiert nach Einrichtungs-Kategorie
    # mit ergänzender Info zur Anzahl Klassen im aktuellen Schuljahr
    InstitutionCategory.where(institution_type: [Institution::TYPE_EDUCATIONAL, Institution::TYPE_SCHOOL]).each do |ic|
      # @available_institutions[ic.name] = ic.institutions.pluck(:name, :id)
      @available_institutions[ic.name] = ic.institutions
        .map{ |i| [
          i == @client.institution ? i.name + " (aktuell)" : i.name,
          i.id, {
          'data-subtext': "#{i.client_groups.where(semester: SystemSetting.get_instance.semester).count} Klassen im aktuellen Schuljahr"
          }] }
    end
  end

  def create
    @client.assign_attributes(client_params)
    authorize!(:update, @client) # a new career item does in fact change the client
    respond_to do |format|
      if @client.save
        # redirect to client group change, as the client group depends on institution
        success = "Die neue Einrichtungszugehörigkeit wurde erfolgreich gespeichert. Die Laufbahn von " + view_context.show_person(@client) + " wurde entsprechend aktualisiert. Nun kann eine neue Klasse ausgewählt werden."
        format.html { redirect_to new_client_career_items_client_group_path(@client), success: success }
      else
        format.html { render :new }
      end
    end
  end


  private
    # Use callbacks to share common setup or constraints between actions.

    def client_params
      params.require(:client).permit(:institution_id, career_items_attributes: [:change_type, :description])
    end

    def set_client
      @client = Client.find(params[:client_id])
    end
end
