class DiagnosticBorrowsController < ApplicationController
  protect_from_forgery :except => [:update]

  def index
    respond_to do |format|
      format.html do
        if params[:teacher_id] # /teacher/:id/diagnostic_borrows
          @teacher = Teacher.where(id: params[:teacher_id]).take!
          @diagnostic_borrows_grid = DiagnosticBorrowsGrid.new(params[:diagnostic_borrows_grid]) do |scope|
            scope.where(teacher_id: params[:teacher_id]).page(params[:page]).per(5)
          end
          add_breadcrumb "Diagnostiken", :diagnostics_path
          add_breadcrumb "Ausgeliehenes von #{@teacher.first_name} #{@teacher.last_name}"
          render :index and return
        end
        if params[:institution_id] # /institutions/:id/diagnostics/:catalog_id/diagnostic_borrows
          @institution = Institution.where(id: params[:institution_id]).take!
          authorize!(:create,DiagnosticBorrow)
          @diagnostic = Diagnostic.where(catalog_id: params[:diagnostic_catalog_id]).take!
          if current_user.is_teacher?
            @teacher = current_user.person
            @diagnostic_borrow_new = DiagnosticBorrow.new(institution_id: params[:institution_id],diagnostic_id:@diagnostic.id,teacher_id: @teacher.id)
          else
            flash[:warning] = "Ausleihe ist nur für Lehrpersonen möglich"
            redirect_to :back and return
          end
          add_breadcrumb "Diagnostiken", :diagnostics_path
          add_breadcrumb "Ausleihe in #{@institution.name}"
          render :calendar and return
        end

      end
      format.json do
        @diagnostic = Diagnostic.where(catalog_id: params[:diagnostic_catalog_id]).take!
        @diagnostic_borrows = @diagnostic.diagnostic_borrows.only_not_returned.where(:institution_id => params[:institution_id]).where('from_date > ? and to_date < ?',params[:start], params[:end])
      end
    end
  end


  def edit
    @diagnostic_borrow = DiagnosticBorrow.where(id: params[:id]).take!
    authorize!(:update, @diagnostic_borrow)
    @diagnostic_borrow.do_return = true
    render layout: false
  end

  def create
    @diagnostic = Diagnostic.where(catalog_id: params[:diagnostic_catalog_id]).take!
    @diagnostic_borrow = DiagnosticBorrow.new(diagnostic_borrow_create_params)
    @diagnostic_borrow.diagnostic_id = @diagnostic.id
    authorize!(:create,  @diagnostic_borrow)
    @diagnostic_borrow.save
    respond_to do |format|
      format.js{}
    end
  end

  def update
    @diagnostic_borrow = DiagnosticBorrow.where(id: params[:id]).take!
    @diagnostic_borrow.assign_attributes(diagnostic_borrow_update_params)
    authorize!(:update,  @diagnostic_borrow)
    @diagnostic_borrow.save
    respond_to do |format|
      format.js{}
      format.html{ redirect_to :back, success: "Rückgabe erfolgreich"}
    end
  end

  private
  def diagnostic_borrow_create_params
    params.require(:diagnostic_borrow).permit(
      :teacher_id, :institution_id, :from_date, :to_date
    )
  end

  def diagnostic_borrow_update_params
    params.require(:diagnostic_borrow).permit(
        :do_return
    )
  end


end
