class PortfolioItemTargetsController < ApplicationController
  include PdfConcern

  def edit
    @portfolio_item_target = ::Portfolio::ItemTarget.where(id: params[:id], evaluate: true).take!
    authorize!(:update, @portfolio_item_target.portfolio_item)
    subjects_breadcrumb(@portfolio_item_target.portfolio_item)
    subject_breadcrumb(@portfolio_item_target.portfolio_item)
    add_breadcrumb "#{@portfolio_item_target.portfolio_item.portfolio_step.name} vom #{l(@portfolio_item_target.portfolio_item.start, format: :short)}", portfolio_item_path(@portfolio_item_target.portfolio_item)
    add_breadcrumb "Evaluationsergebnisse eintragen"
    respond_to do |format|
      format.html { render :edit }
      format.pdf { render_pdf(
          "#{@portfolio_item_target.portfolio_item.portfolio_step.name}-#{@portfolio_item_target.portfolio_item.portfolio_subject.name}-#{l(@portfolio_item_target.portfolio_item.start,format: :short)}-Zielvereinbarung.pdf",
          :edit,
          title: "#{@portfolio_item_target.portfolio_item.portfolio_step.name}_#{@portfolio_item_target.portfolio_item.portfolio_subject.name}_Zielvereinbarung",
          header_left: "#{@portfolio_item_target.portfolio_item.portfolio_step.name} - #{@portfolio_item_target.portfolio_item.portfolio_subject.name} Zielvereinbarung",
          header_right: "#{l(@portfolio_item_target.portfolio_item.start,format: :short)}"
      )
      }
    end

  end

  def update
    @portfolio_item_target = ::Portfolio::ItemTarget.where(id: params[:id], evaluate: true).take!
    authorize!(:update, @portfolio_item_target.portfolio_item)
    # ATTENTION: There is no authorization check at this point, that one can only update their own results.
    # ATM this is only done in view, which is not sufficient when user crafts request.
    @portfolio_item_target.assign_attributes(portfolio_item_target_params)
    subjects_breadcrumb(@portfolio_item_target.portfolio_item)
    subject_breadcrumb(@portfolio_item_target.portfolio_item)
    add_breadcrumb "#{@portfolio_item_target.portfolio_item.portfolio_step.name} vom #{l(@portfolio_item_target.portfolio_item.start, format: :short)}", portfolio_item_path(@portfolio_item_target.portfolio_item)
    add_breadcrumb "Evaluationsergebnisse eintragen"
    respond_to do |format|
      if @portfolio_item_target.save
        format.html { redirect_to @portfolio_item_target.portfolio_item.portfolio_subject.redirect_after_item_create,  success: 'Gespeichert'}
      else
        flash.now[:danger] = 'Bitte prüfen Sie Ihre Eingaben'
        format.html { render :edit }
      end
    end

  end

  private
  def portfolio_item_target_params
    params.require(:portfolio_item_target).permit(
        :result_comment,:is_successful,
        results_attributes: [
            :id,:result_value,:result_comment,:evaluative_id,:evaluative_type,:result_scheme
        ]
    )
  end
  def subjects_breadcrumb(portfolio_item)
    case portfolio_item.portfolio.subject.class.name
      when 'Client'
        add_breadcrumb "SchülerInnen", :clients_path, title: "alle SchülerInnen anzeigen"
      when 'ClientGroup'
        add_breadcrumb "Einrichtung", institution_path(portfolio_item.portfolio_subject.institution), title: "#{portfolio_item.portfolio_subject.institution.name}"
    end

  end

  def subject_breadcrumb(portfolio_item)
    case portfolio_item.portfolio.subject.class.name
      when 'Client'
        add_breadcrumb "#{view_context.show_person(portfolio_item.portfolio.subject)}", dashboard_client_path(portfolio_item.portfolio.subject), title: "Übersicht anzeigen"
      when 'ClientGroup'
        add_breadcrumb "Klasse #{portfolio_item.portfolio_subject.name}", client_group_path(portfolio_item.portfolio.subject), title: "Klassenübersicht anzeigen"
    end
  end

end
