class TeacherInstitutionCategoriesController < ApplicationController

  before_action :set_teacher_institution_category, only: [:show, :edit, :update, :destroy]

  before_action do
    authorize!(:update, :system_configuration)
  end

  def index
    @teacher_institution_categories_grid = TeacherInstitutionCategoriesGrid.new(params[:teacher_institution_categories_grid]) do |scope|
      scope.page(params[:page]).per(5)
    end
    add_breadcrumb "Systemeinstellungen", configurations_path
    add_breadcrumb "Einsatz von Lehrern an Einrichtungen", teacher_institution_categories_path
  end


  def new
    @teacher_institution_category = TeacherInstitutionCategory.new
    add_breadcrumb "Systemeinstellungen", configurations_path
    add_breadcrumb "Einsatz von Lehrern an Einrichtungen", teacher_institution_categories_path
    add_breadcrumb "Neue Einsatzart", new_teacher_institution_category_path
  end

  def edit
    add_breadcrumb "Systemeinstellungen", configurations_path
    add_breadcrumb "Einsatz von Lehrern an Einrichtungen", teacher_institution_categories_path
    add_breadcrumb "#{@teacher_institution_category.name} bearbeiten", edit_teacher_institution_category_path(@teacher_institution_category)
  end

  def create
    @teacher_institution_category = TeacherInstitutionCategory.new(teacher_institution_category_params)
    respond_to do |format|
      if @teacher_institution_category.save
        format.html { redirect_to teacher_institution_categories_path, success: 'Gespeichert' }
      else
        format.html { render :new }
      end
    end
  end

  def update
    respond_to do |format|

      if @teacher_institution_category.update(teacher_institution_category_params)
        format.html { redirect_to teacher_institution_categories_path, success: 'Gespeichert' }
      else
        format.html { render :edit }
      end
    end
  end

  def destroy
    respond_to do |format|
      if @teacher_institution_category.is_destructable?
        @teacher_institution_category.destroy
        format.html { redirect_to teacher_institution_categories_path, success: 'Gelöscht' }
      else
        format.html { redirect_to teacher_institution_categories_path, warning: 'Kann nicht gelöscht werden.' }
      end
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_teacher_institution_category
      @teacher_institution_category = TeacherInstitutionCategory.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def teacher_institution_category_params
      params.require(:teacher_institution_category).permit(:name, :description, :is_management)
    end
end
