class ClientGuardianRelationGrid < BaseGrid

  scope do
    ClientGuardianRelation.all.joins(:client).joins(:guardian).order('guardians.last_name DESC')
  end

  filter(:guardian_name, :string, header: "Name") do |value, scope|
    value.split.inject(scope) do |_scope, part|
      _scope.where("guardians.first_name ILIKE '%#{part}' OR guardians.last_name ILIKE '%#{part}'")
    end
  end

  filter(:client_name, :string, header: "SchülerIn") do |value, scope|
    value.split.inject(scope) do |_scope, part|
      _scope.where("clients.first_name ILIKE '%#{part}%' OR clients.last_name ILIKE '%#{part}%'")
    end
  end

  column(:guardian_name, header: "Name", html: true)  do |cgr|
    show_guardian(cgr.guardian)
  end

  column(:client_name, header: "Schüler", html: true) do |cgr|
    show_client(cgr.client)
  end

  column(:email, header: "E-Mail", html: true)  do |cgr|
    cgr.guardian.email
  end

  column(:email, header: "Telefon", html: true)  do |cgr|
    cgr.guardian.phone
  end

  column(:email, header: "Mobil", html: true)  do |cgr|
    cgr.guardian.mobile
  end

  column(:actions,  header: '', html: true) do |cgr|

    if can? :update, cgr.client
      anchor = 'client-tab-'
      case cgr[:category]
      when ClientGuardianRelation::ENUM_CATEGORY_FATHER , ClientGuardianRelation::ENUM_CATEGORY_MOTHER
        anchor += '4'
      when ClientGuardianRelation::ENUM_CATEGORY_FOSTER
        anchor += '5'
      else
        anchor += '6'
      end
      
      link = link_to(content_tag(:i, "", class: "glyphicon glyphicon-pencil"), edit_client_path(cgr.client, anchor: anchor), {title: "bearbeiten", class: "btn btn-success btn-sm", role: "button"}).html_safe

      "<div class='btn-group btn-group-nowrap-1 btn-group-xs  pull-right'>
        #{link}  
      </div>".html_safe
    end
  end

end
