class PerformClientDuplicateDetectionRequestJob < ActiveJob::Base
  queue_as :default

  rescue_from ActiveJob::DeserializationError do |e|
    message = "\e[31m\e[1m#{e.message}\e[22m\e[0m" # make read and bold
    Rails.logger.error(message)
  end

  def perform(*client_duplicate_detection_requests)
    client_duplicate_detection_requests.each do |client_duplicate_detection_request|
      begin
        possible_duplicates_clients_table = Client.get_possible_duplicates( client_duplicate_detection_request.first_name, client_duplicate_detection_request.last_name, client_duplicate_detection_request.gender == 'f' ? :w : :m, client_duplicate_detection_request.bday)
        possible_duplicates_clients_table.each do |client|
          begin
            client_duplicate_detection_request.client_duplicate_detections.create!({
                first_name: client.first_name,
                last_name: client.last_name,
                gender: Client.genders[client.gender] == Client::ENUM_GENDER_MALE ? 'm' : 'f',
                bday: client.bday,
                client_id: client.id, # unique key that will raise Error on subsequent runs
                client_duplicate_request_id: nil,
                institution_name: client.institution.name,
                client_group_name: client.client_group ?  client.client_group.name : "keine Klasse",
                duplicate_type: 'Client'
            })
          rescue ActiveRecord::RecordNotUnique => e
            Rails.logger.debug(e.message)
          end
        end
        possible_duplicates_pending_table = []
        unless client_duplicate_detection_request.vsb_id == SystemSetting.get_instance.vsb_id
          possible_duplicates_pending_table = ClientDuplicateRequest.get_possible_duplicates( client_duplicate_detection_request.first_name, client_duplicate_detection_request.last_name,client_duplicate_detection_request.gender == 'f' ? :w : :m,client_duplicate_detection_request.bday)
          possible_duplicates_pending_table.each do |c|
            begin
              client_duplicate_detection_request.client_duplicate_detections.create!({
                 first_name: c.first_name,
                 last_name: c.last_name,
                 gender: c.gender,
                 bday: c.bday,
                 client_id: nil,
                 client_duplicate_request_id: c.id, # unique key that will raise Error on subsequent runs
                 institution_name: nil,
                 client_group_name: nil,
                 duplicate_type: 'ClientDuplicateRequest'})
            rescue ActiveRecord::RecordNotUnique => e
              Rails.logger.debug(e.message)
            end
          end
        end
        # this value is passed alongside the duplicate results to csb, as the requests can be executed in any order. Csb considers the job finished when the result count matches
        # the announced result count
        client_duplicate_detection_request.update_column(:announced_duplicate_count, possible_duplicates_clients_table.size + possible_duplicates_pending_table.size)
        client_duplicate_detection_request.request_performed!
        AnnounceDuplicateTotalJob.perform_later(client_duplicate_detection_request)
      rescue StandardError => e
        client_duplicate_detection_request.request_failed!
        message = "\e[31m\e[1m#{e.message}\e[22m\e[0m" # make read and bold
        Rails.logger.error message
      end
    end
  end

end
