class ReturnClientDuplicateDetectionJob < ActiveJob::Base
  queue_as :default

  rescue_from ActiveJob::DeserializationError do |e|
    message = "\e[31m\e[1m#{e.message}\e[22m\e[0m" # make read and bold
    Rails.logger.error(message)
  end

  def perform(*client_duplicate_detections)
    client_duplicate_detections.each do |client_duplicate_detection|
      begin
        client_id = client_duplicate_detection.client_id if client_duplicate_detection.duplicate_type == 'Client'
        client_id = client_duplicate_detection.client_duplicate_request_id if client_duplicate_detection.duplicate_type == 'ClientDuplicateRequest'
        CsbApi::ClientDuplicateDetectionResult.create!({
             'client-duplicate-detection-query-id' => client_duplicate_detection.client_duplicate_detection_request.client_duplicate_detection_query_id,
             #'client-duplicate-detection-id' => client_duplicate_detection.client_duplicate_request_id,
             'bday' => client_duplicate_detection.bday,
             'client-id' => client_id,
             'duplicate-type' => client_duplicate_detection.duplicate_type,
             'first-name' => client_duplicate_detection.first_name,
             'last-name' => client_duplicate_detection.last_name,
             'gender' => client_duplicate_detection.gender,
             'institution-name' => client_duplicate_detection.institution_name,
             'client-group-name' => client_duplicate_detection.client_group_name,
         })
         set_success(client_duplicate_detection)
      rescue JsonApiClient::Errors::ConnectionError, JsonApiClient::Errors::ServerError => e
        set_recoverable_error(client_duplicate_detection,e.message)
      rescue StandardError, JsonApiClient::Errors::ValidationError => e
        set_fatal_error(client_duplicate_detection,e.message)
      end
    end
  end

  private
  def set_success(client_duplicate_detection)
    client_duplicate_detection.return_performed!
    Rails.logger.debug("Successful return client_duplicate_detection.id=#{client_duplicate_detection.id} for duplicate detection query: #{client_duplicate_detection.client_duplicate_detection_request.client_duplicate_detection_query_id}")
  end
  def set_recoverable_error(client_duplicate_detection,message)
    if client_duplicate_detection.retry_count <= 2
      client_duplicate_detection.increment! :retry_count
      retry_job wait: (client_duplicate_detection.retry_count * client_duplicate_detection.retry_count).seconds
      client_duplicate_detection.return_retry!
      Rails.logger.info(message)
    else
      client_duplicate_detection.return_failed!
      message = "\e[31m\e[1m#{message}\e[22m\e[0m" # make read and bold
      Rails.logger.error(message)
    end
  end
  def set_fatal_error(client_duplicate_detection,message)
    client_duplicate_detection.return_failed!
    message = "\e[31m\e[1m#{message}\e[22m\e[0m" # make read and bold
    Rails.logger.error(message)
  end
end
