class ClientGroupHistory < ActiveRecord::Base
  
  #--- Associations
  belongs_to :client_group
  belongs_to :teacher

  #--- Callback definitions
  before_create :set_defaults_for_new
  before_create :discard_previous_changes_on_same_day
  after_create :end_earlier_record
  
  private

    def set_defaults_for_new
      self.start_date = Date.today
      self.client_group_id = client_group.id
      self.teacher_id = teacher.id
    end

    def discard_previous_changes_on_same_day
      self.class.where(client_group: client_group, start_date: start_date).delete_all
    end

    def end_earlier_record
      self.class
        .where(client_group: client_group, end_date: nil)
        .where.not(id: [self.id])
        .update_all(end_date: start_date)
    end

end
