class ClientGuardianRelation < ActiveRecord::Base

  ENUM_CATEGORY_FATHER = 0
  ENUM_CATEGORY_MOTHER = 1
  ENUM_CATEGORY_FOSTER = 2
  ENUM_CATEGORY_LEGAL = 3
  ENUM_CATEGORY_CUSTODY = 4


  #--- Associations
  belongs_to :client, inverse_of: :client_guardian_relations
  belongs_to :guardian, inverse_of: :client_guardian_relations
  accepts_nested_attributes_for :guardian, reject_if: :all_blank, allow_destroy: true

  #--- Scopes
  scope :related, -> { where(category: [ENUM_CATEGORY_FATHER, ENUM_CATEGORY_MOTHER]) }
  scope :foster, -> { where(category: [ENUM_CATEGORY_FOSTER]) }
  scope :legal, -> { where(category: [ENUM_CATEGORY_LEGAL, ENUM_CATEGORY_CUSTODY]) }

  #--- Callback definitions

  #--- Attributes
  enum category: { "Vater": ENUM_CATEGORY_FATHER, "Mutter": ENUM_CATEGORY_MOTHER, "Pflegeeltern": ENUM_CATEGORY_FOSTER, "Vormundschaft": ENUM_CATEGORY_LEGAL, "Pflege für Personensorge": ENUM_CATEGORY_CUSTODY }

  #--- Validations
  validates :category, presence: true
  validates :client, presence: true

  validate do
    unless guardian.present?
      errors.add(:guardian,'Es muss eine Person gesetzt werden')
    end
    if guardian.present? && guardian.new_record? && duplicate_guardians.exists? && !save_anyway
      errors.add(:duplicate_guardians)
      self.save_anyway=true
    end
  end
  attr_accessor :save_anyway


  def duplicate_guardians
    ::Guardian
        .where(first_name_phonetic_code: guardian.first_name.phonetic_code)
        .where(last_name_phonetic_code: guardian.last_name.phonetic_code)
        .where(gender: ::Guardian.genders[guardian.gender])
  end


end
