class FormerCareerItem < ActiveRecord::Base
  self.table_name = 'career_items'
  default_scope  { joins(:client).where("date_trunc('day',  clients.created_at) > start_at").order(start_at: :desc,created_at: :desc) }

  #--- Associations
  belongs_to :client        # never NULL

  #--- Validations
  validates :client_id,:change_type, presence: true # is dependent on client
  validates :start_at, presence: true
  validate :start_at do |item|
    errors.add(:start_at, 'Nur alte Einträge können nachgetragen werden') if start_at >= item.client.created_at
  end
  validates :client_group_name, presence: {if: ->{ change_type == CareerItem::CHANGE_TYPE_CLIENT_GROUP}}
  validates :institution_name, presence: {if: ->{ change_type == CareerItem::CHANGE_TYPE_INSTITUTION}}
  validates :teacher_name, presence: {if: ->{ change_type == CareerItem::CHANGE_TYPE_TEACHER}}
  validates :change_type, inclusion: {in: :allowed_change_types}

  validates :end_at,            absence: true, on: :create
  validates :portfolio_level,   absence: true
  validates :client_group_id,   absence: true
  validates :teacher_id,        absence: true
  validates :institution_id,    absence: true

  #--- Restricted on update
  attr_readonly :end_at, :portfolio_level, :client_group_id, :teacher_id, :institution_id, :change_type

  def allowed_change_types
    [CareerItem::CHANGE_TYPE_CLIENT_GROUP,CareerItem::CHANGE_TYPE_INSTITUTION,CareerItem::CHANGE_TYPE_TEACHER]
  end



  #--- Callback definitions
  before_create do
    self.effective_date = start_at
    self.portfolio_level = 0
  end
  before_save do
    _next = CareerItem.where(client_id: client_id, change_type: change_type).where('start_at >= ?',start_at).order(start_at: :asc,created_at: :asc).first
    _previous = CareerItem.where(client_id: client_id, change_type: change_type).where('end_at <= ?',start_at).order(end_at: :desc,created_at: :desc).first
    self.end_at = _next.start_at unless _next.nil?
    _previous.end_at = self.start_at unless _previous.nil?
    _previous.save unless _previous.nil?
    if persisted? && start_at_changed?
      _next_before_change = CareerItem.where(client_id: client_id, change_type: change_type).where('start_at >= ?',start_at_was).order(start_at: :asc,created_at: :asc).first
      _previous_before_change = CareerItem.where(client_id: client_id, change_type: change_type).where('end_at <= ?',start_at_was).order(end_at: :desc,created_at: :desc).first
      _previous_before_change.end_at = _next_before_change.start_at unless _next_before_change.nil? || _previous_before_change.nil?
      _previous_before_change.save unless _previous_before_change.nil?
    end
  end

end
