class InstitutionDocument < ActiveRecord::Base

  include AuthorConcern

  #--- CW File Uploader
  mount_uploader :file, InstitutionFileUploader

  belongs_to :institution

  has_many :documents, :class_name => 'InstitutionDocument', :foreign_key => 'parent_id'
  belongs_to :folder, :class_name => 'InstitutionDocument', :foreign_key => 'parent_id'

  has_many :all_parent_institution_document_hierarchies, :class_name => 'InstitutionDocumentHierarchy', :foreign_key => 'child_id'
  has_many :all_parent_folders, -> { order 'level desc' }, through: :all_parent_institution_document_hierarchies, source: :parent

  has_many :all_child_institution_document_hierarchies, :class_name => 'InstitutionDocumentHierarchy', :foreign_key => 'parent_id'
  has_many :all_children, -> { order 'level desc' }, through: :all_child_institution_document_hierarchies, source: :child

  def is_folder?
    !file.present?
  end

  before_save do
    if step_type_changed?
      st = CsbApi::PortfolioStepType.where(step_type: step_type).first
      self.step_type_description = st[:description]
    end
  end


  validate do
    if is_folder? && !description.present?
      errors.add :description, "Bitte einen Ordnernamen angeben."
    end
  end

  validates :institution, presence: { message: "Einrichtung fehlt" }

end
