module Portfolio
  class Condition < ::ActiveRecord::Base
    self.table_name = 'portfolio_conditions'
    self.inheritance_column =nil


    belongs_to :portfolio_rule,
               class_name: '::Portfolio::Rule',
               inverse_of: :portfolio_conditions,
               foreign_key: 'rule_id'

    has_and_belongs_to_many :portfolio_steps,
                            class_name: '::Portfolio::Step'


    after_initialize :init

    attr_reader :all_matchers, :all_portfolio_matchers

    def init
      @matches = {}
      @all_matchers = []
      unless item_matchers.nil?
        @all_matchers =  ::JSON.parse(item_matchers).map do |object|
          instance = nil
          klass = "::Portfolio::Conditions::#{matcher_name(object['type']).camelize}"
          begin
            instance = klass.constantize.new
            instance.condition = self
            object['args'].each do |k, v|
              instance.send(k+'=', v) if instance.respond_to? k+'='
            end unless object['args'].nil?
            @matches[matcher_name(object['type'])] = true
          rescue ::NameError
          end
          instance
        end
      end
      @all_portfolio_matchers = []
      unless portfolio_matchers.nil?
        @all_portfolio_matchers =  ::JSON.parse(portfolio_matchers).map do |object|
          instance = nil
          klass = "::Portfolio::Conditions::#{matcher_name(object['type']).camelize}"
          begin
            instance = klass.constantize.new
            object['args'].each do |k, v|
              instance.send(k+'=', v) if instance.respond_to? k+'='
            end unless object['args'].nil?
            @matches[matcher_name(object['type'])] = true
          rescue ::NameError
          end
          instance
        end
      end
    end

    def has_matcher?(name)
      @matches.key?(name) || @matches.key?(matcher_name(name))
    end

    def steps_match?(item)
      #Rails.logger.debug("T4K3Th!5: (#{portfolio_steps.map(&:name).join(',')}).include?(#{item.portfolio_step.name})")
      portfolio_steps.map(&:name).include?(item.portfolio_step.name)
    end

    def match_portfolio?(enumerator)
      return @all_portfolio_matchers.inject(true) do |and_match,matcher|
        and_match & matcher.match?(enumerator)
      end
    end

    def match_item?(portfolio_item)
      unless portfolio_item.portfolio_step.present?
        return false
      end
      unless steps_match?(portfolio_item)
        return false
      end
      return @all_matchers.inject(true) do |and_match,matcher|
        and_match & matcher.match?(portfolio_item)
      end
    end

    private
    def matcher_name(name)
      map={
          'commented_item' => 'commented_item_matcher',
          'special_ed_extern' => 'special_ed_extern_matcher',
          'questionnaire' => 'questionnaire_matcher',
          'checklist' => 'checklist_matcher',
          'class_teacher' => 'class_teacher_involved_matcher',
          'class_teacher_involved' => 'class_teacher_involved_matcher',
          'evaluation' => 'evaluation_completion_matcher',
          'evaluation_completion' => 'evaluation_completion_matcher',
          'management' => 'management_involved_matcher',
          'management_involved' => 'management_involved_matcher',
          'no_evaluation' => 'no_evaluation_matcher',
          'result' => 'specific_result_matcher',
          'specific_result' => 'specific_result_matcher',
          'special_ed' => 'special_ed_involved_matcher',
          'special_ed_involved' => 'special_ed_involved_matcher',
          'support_teacher' => 'support_teacher_involved_matcher',
          'support_teacher_involved' => 'support_teacher_involved_matcher',
          'target' => 'target_agreement_present_matcher',
          'target_agreement_present' => 'target_agreement_present_matcher',
          'document' => 'specific_document_uploaded_matcher',
          'specific_document_uploaded' => 'specific_document_uploaded_matcher',
          'special_ed_associated' => 'special_ed_associated_matcher',
          'initial_special_ed_necessary' => 'initial_special_ed_necessary_matcher'
      }
      if map.key?(name)
        return map[name]
      end
      return name
    end

  end
end
