module Portfolio
  class Enumerator < ::Enumerator

      attr_reader :current_item, :documents


      def initialize(items)
        @portfolio = items.to_a.sort(&by_start_and_level)
        @documents = Set.new()
        super() do |yielder|
          @portfolio.each do |item|
            collect_aggregate(item)
            @current_item = item
            yielder << item
          end
        end
      end

      # iterates up to the first item that has the given level
      def forward_to_level(level)
        self.next while (self.next? && self.peek.portfolio_level < level)
      end

      def to_a
        @portfolio
      end

      def next?
        return true if peek rescue StopIteration; false
      end

      def add(item)
        replace = nil
        @portfolio.each_with_index do |_item, i|
          if _item.id == item.id
            replace = i
          end
        end
        if replace.present?
          @portfolio[replace] = item
        else
          @portfolio << item
          @portfolio.sort(&by_start_and_level)
        end
        find do |i|
          if item.new_record?
            i.object_id == item.object_id
          else
            i.id == item.id
          end
        end
        self
      end

      private
      def collect_aggregate(item)
        item.portfolio_documents.reject(&:marked_for_destruction?).each do |doc|
          if doc.portfolio_document_type.present?
            @documents.add(doc.portfolio_document_type.name)
          end
        end
      end
      def by_start_and_level
        Proc.new { |i1, i2| c=i1.start <=> i2.start; c=i1.portfolio_level <=> i2.portfolio_level if c == 0; c=i1.created_at <=> i2.created_at if c == 0; c }
      end

  end
end
