module Portfolio
  class ItemEvaluationDbr < ::ActiveRecord::Base
    self.table_name = 'portfolio_item_evaluation_dbrs'
    self.inheritance_column = nil


    has_one   :portfolio_item_evaluation,
               foreign_key: :portfolio_item_evaluation_dbr_id,
               class_name: '::Portfolio::ItemEvaluation',
               inverse_of:  :portfolio_item_evaluation_dbr
    delegate :portfolio_item, to: :portfolio_item_evaluation
    delegate :portfolio, to: :portfolio_item
    delegate :portfolio_subject, to: :portfolio_item

    has_many  :characteristics,
                class_name: '::Portfolio::ItemEvaluationDbrCharacteristic',
                foreign_key: :portfolio_item_evaluation_dbr_id,
                inverse_of:  :dbr,
                dependent: :destroy
    accepts_nested_attributes_for :characteristics, reject_if: :all_blank, allow_destroy: true

    has_many  :results,
              class_name: '::Portfolio::ItemEvaluationDbrResult',
              foreign_key: :portfolio_item_evaluation_dbr_id,
              inverse_of:  :dbr,
              dependent: :destroy
    accepts_nested_attributes_for :results, allow_destroy: true

    after_save do
      _results = results.to_a
      _existing_count = {}
      characteristics.each do |characteristic|
        _existing_count[characteristic] ||= {}
        lines.each_index  do |j|
          _existing_count[characteristic][j] = _results.select{|r|r.portfolio_item_evaluation_dbr_characteristic_id==characteristic.id && r.line_idx==j}.size
        end
      end
      characteristics.each do |characteristic|
        lines.each_index  do |j|
          (number_of_data_points - _existing_count[characteristic][j]).times do
             results.create(characteristic: characteristic, line_idx: j)
          end
        end
      end
      characteristics.each do |characteristic|
        results.select{|r|r.line_idx >=lines.length && r.portfolio_item_evaluation_dbr_characteristic_id==characteristic.id}.each(&:mark_for_destruction)
      end
      true
    end

    def lines
      if baselines_amount == 0
        return ['Interventionsphase']
      end
      if baselines_amount == 1
        ary = []
        baselines_amount.times do |i|
          ary << "Grundrate"
          ary << "Interventionsphase"
        end
        return ary
      end
      if baselines_amount > 1
        ary = []
        baselines_amount.times do |i|
          ary << "#{i+1}. Grundrate"
          ary << "#{i+1}. Interventionsphase"
        end
        return ary
      end
    end

    validates :range_begin, :range_end,:setting_social,:setting_time,:number_of_data_points, presence: true
    validates :range_begin , numericality:  { only_integer: true, greater_than_or_equal_to: 0 }
    validates :range_end , numericality:  { only_integer: true,  lesser_than_or_equal_to: 100 }
    validates :setting_social, :setting_time , length: { maximum: 280, minimum: 10}
    validates :number_of_data_points , numericality: { only_integer: true, greater_than: 0 }
    validates :baselines_amount , numericality: { only_integer: true, greater_than: -1, lesser_than: 3 }
    validate do
      errors.add(:characteristics, "Maximal 5 Merkmale können erfasst werden.") if (characteristics.size > 5)
      errors.add(:characteristics, "Mindestens 1 Merkmal sollte erfasst werden.") if (characteristics.size < 1)
    end





  end
end


