module Portfolio
  class ItemTarget < ::ActiveRecord::Base
      self.table_name = 'portfolio_item_targets'
      self.inheritance_column = nil

      include ::Publishable

      belongs_to :portfolio_item,
                 foreign_key: :portfolio_item_id,
                 class_name: '::Portfolio::Item',
                 inverse_of: :target_agreements
      delegate :portfolio, to: :portfolio_item
      delegate :portfolio_subject, to: :portfolio_item

      has_many :results,
               foreign_key: :portfolio_item_target_id,
               class_name: '::Portfolio::ItemTargetResult',
               dependent: :destroy # refs #192
      accepts_nested_attributes_for :results, reject_if: :not_evaluate?

      has_one :evaluation,
              foreign_key: :portfolio_item_target_id,
              class_name: '::Portfolio::ItemEvaluation',
              inverse_of:  :portfolio_item_target,
              dependent: :destroy # refs #192
      accepts_nested_attributes_for :evaluation, reject_if: :not_evaluate?

      has_many :teacher_results, -> { where(evaluative_type: 'Teacher') },
               foreign_key: :portfolio_item_target_id,
               class_name: '::Portfolio::ItemTargetResult'

      has_many :guardian_results, -> { where(evaluative_type: 'Guardian') },
               foreign_key: :portfolio_item_target_id,
               class_name: '::Portfolio::ItemTargetResult'

      has_many :supporter_results, -> { where(evaluative_type: 'Supporter') },
               foreign_key: :portfolio_item_target_id,
               class_name: '::Portfolio::ItemTargetResult'

      has_many :person_results, -> { where(evaluative_type: 'Portfolio::EvaluationInvolvedPerson') },
               foreign_key: :portfolio_item_target_id,
               class_name: '::Portfolio::ItemTargetResult'

      has_one :subject_result, -> { where(evaluative_type: ::Portfolio::Subjects::Base.all_subjects ) },
              foreign_key: :portfolio_item_target_id,
              class_name: '::Portfolio::ItemTargetResult'



      validates :portfolio_item, presence: true
      validates :evaluation, presence: true, if: Proc.new { |record| record.evaluate == true }
      validates :content, length: {minimum: 1}
      validates :evaluate, inclusion: [ true,false ]

      def evaluation_completed
        return false unless results.any?
        results.each do |result|
          if result.result_value.nil?
            return false
            break
          end
        end
        true
      end

      private
      def not_evaluate?
        ! evaluate?
      end
    end
end
