module Questionnaires
  class ItrfTeacher < Questionnaire

    def accepts_teacher?
      true
    end

    def self.questionnaire_name
      "ITRF (Volpe et al. 2018)"
    end

    # @return Hash[String]
    def documents
      {
         #'Fragebogen-Schüler' => Rails.public_path + '/questionnaires/itrf/ITRF-Kurzversion.pdf'
      }
    end

    def link
      nil
    end
    
    def result_texts
      [
          "Verhalten ist nicht problematisch",
          "Verhalten ist leicht problematisch",
          "Verhalten ist mäßig problematisch",
          "Verhalten ist stark problematisch"
      ]
    end

    def groups
      # ATTENTION: Do not change ids of Questions and QuestionGroups. Do not change values.
      values = [0,1,2,3]
      [
          Questionnaire::QuestionGroup.new(1,1,"Unproduktives Arbeitsverhalten",[
              Questionnaire::Question.new(1,1,"Stellt Unterrichtsaufgaben nicht rechtzeitig fertig",values),
              Questionnaire::Question.new(2,2,"Beginnt mit der Aufgabenbearbeitung nicht selbstständig",values),
              Questionnaire::Question.new(3,3,"Erledigt Hausaufgaben unvollständig",values),
              Questionnaire::Question.new(4,4,"Zeigt Unterrichtsaufgaben nicht selbstständig vor",values),
              Questionnaire::Question.new(5,5,"Kontrolliert seine eigene Arbeit nicht",values),
              Questionnaire::Question.new(6,6,"Nimmt Materialien, die zu Hause benötigt werden, nicht mit (z.B. für die Hausaufgaben, Elternbriefe)",values),
              Questionnaire::Question.new(7,7,"Kommt unvorbereitet zum Unterricht",values),
              Questionnaire::Question.new(8,8,"Beteiligt sich nicht am Unterricht",values)
          ]),
          Questionnaire::QuestionGroup.new(2,2,"Störendes Verhalten",[
              Questionnaire::Question.new(9,9,"Streitet und zankt mit Lehrkräften",values),
              Questionnaire::Question.new(10,10,"Verliert die Beherrschung",values),
              Questionnaire::Question.new(11,11,"Stört andere",values),
              Questionnaire::Question.new(12,12,"Verwendet unangemessene Sprache",values),
              Questionnaire::Question.new(13,13,"Hat Konflikte mit Mitschülerinnen und Mitschülern",values),
              Questionnaire::Question.new(14,14,"Kommandiert herum",values),
              Questionnaire::Question.new(15,15,"Macht unangebrachte Bemerkungen",values),
              Questionnaire::Question.new(16,16,"Respektiert nicht die Privatsphäre anderer",values)
          ])
      ]
    end


    # @return Array[Questionnaire::Analysis]
    def analyses
      analyses=[]
      # Gesamtproblemwert
      all_questions_regarding_problems = questionnaire_results.select{|r| [1,2].include?(r.group_id) }
      filled_questions_regarding_problems = all_questions_regarding_problems.select{|r| r.result.present?}
      if filled_questions_regarding_problems.size == all_questions_regarding_problems.size # >= 12
        scaleing = (all_questions_regarding_problems.size.to_f / filled_questions_regarding_problems.size.to_f)
        value = filled_questions_regarding_problems.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(1,1,"Gesamtproblemwert",value, left_maximum: 13, right_minimum: 13)
      end

      # Einzelne Bereiche
      all_questions_group_1 = questionnaire_results.select{|r| r.group_id == 1 }
      filled_questions_group_1 = all_questions_group_1.select{|r| r.result.present?}
      if filled_questions_group_1.size == all_questions_group_1.size # >= 4
        scaleing = (all_questions_group_1.size.to_f / filled_questions_group_1.size.to_f)
        value = filled_questions_group_1.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(2,2,"Unproduktives Arbeitsverhalten",value, left_maximum: 10, right_minimum: 10)
      end
      all_questions_group_2 = questionnaire_results.select{|r| r.group_id == 2 }
      filled_questions_group_2 = all_questions_group_2.select{|r| r.result.present?}
      if filled_questions_group_2.size == all_questions_group_2.size #  >= 4
        scaleing = (all_questions_group_2.size.to_f / filled_questions_group_2.size.to_f)
        value = filled_questions_group_2.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(3,3,"Störendes Verhalten",value, left_maximum: 5, right_minimum: 5)
      end
      analyses
    end



  end
end
