module Questionnaires
  class SdqClient < Questionnaire

    def accepts_client?
      true
    end

    def self.questionnaire_name
      "SDQ (Goodman, 1997) für Schüler"
    end

    # @return Hash[String]
    def documents
      {
         'Auswertung-Schüler' => Rails.public_path + '/questionnaires/sdq/SDQ-Auswertung-Schüler.pdf',
         'Fragebogen-Schüler' => Rails.public_path + '/questionnaires/sdq/SDQ-Schüler.pdf'
      }
    end

    def link
      "http://www.sdqinfo.com/py/sdqinfo/b0.py"
    end
    
    def result_texts
      [
          "Nicht zutreffend",
          "Teilweise zutreffend",
          "Eindeutig zutreffend"
      ]
    end

    def groups
      # ATTENTION: Do not change ids of Questions and QuestionGroups. Do not change values.
      values = [0,1,2]
      reverse_values = [2,1,0]
      [
          Questionnaire::QuestionGroup.new(1,1,"Emotionale Probleme",[
              Questionnaire::Question.new(1,3,"Ich habe häufig Kopfschmerzen oder Bauchschmerzen; mir wird oft schlecht",values),
              Questionnaire::Question.new(2,8,"Ich mache mir häufig Sorgen",values),
              Questionnaire::Question.new(3,13,"Ich bin oft unglücklich oder niedergeschlagen; ich muss häufig weinen",values),
              Questionnaire::Question.new(4,16,"Neue Situationen machen mich nervös; ich verliere leicht das Selbstvertrauen",values),
              Questionnaire::Question.new(5,24,"Ich habe viele Ängste; ich fürchte mich leicht",values)
          ]),
          Questionnaire::QuestionGroup.new(2,2,"Verhaltensprobleme",[
              Questionnaire::Question.new(6,5,"Ich werde leicht wütend; ich verliere oft meine Beherrschung",values),
              Questionnaire::Question.new(7,7,"Normalerweise tue ich, was man mir sagt",reverse_values),
              Questionnaire::Question.new(8,12,"Ich schlage mich häufig; ich kann Andere zwingen zu tun, was ich will",values),
              Questionnaire::Question.new(9,18,"Andere behaupten oft, dass ich lüge oder mogele",values),
              Questionnaire::Question.new(10,22,"Ich nehme Dinge, die mir nicht gehören (von zu Hause, in der Schule oder anderswo)",values)
          ]),
          Questionnaire::QuestionGroup.new(3,3,"Hyperaktivität",[
              Questionnaire::Question.new(11,2,"Ich bin oft unruhig; ich kann nicht lange stillsitzen",values),
              Questionnaire::Question.new(12,10,"Ich bin dauernd in Bewegung und zappelig",values),
              Questionnaire::Question.new(13,15,"Ich lasse mich leicht ablenken; ich finde es schwer, mich zu konzentrieren",values),
              Questionnaire::Question.new(14,21,"Ich denke nach, bevor ich handele",reverse_values),
              Questionnaire::Question.new(15,25,"Was ich angefangen habe, mache ich zu Ende; ich kann mich lange genug konzentrieren",reverse_values)
          ]),
          Questionnaire::QuestionGroup.new(4,4,"Verhaltensprobleme mit Gleichaltrigen",[
              Questionnaire::Question.new(16,6,"Ich bin meistens für mich alleine; ich beschäftige mich lieber mit mir selbst",values),
              Questionnaire::Question.new(17,11,"Ich habe einen oder mehrere gute Freunde oder Freundinnen",reverse_values),
              Questionnaire::Question.new(18,14,"Im allgemeinen bin ich bei Gleichaltrigen beliebt",reverse_values),
              Questionnaire::Question.new(19,19,"Ich werde von anderen gehänselt oder schikaniert",values),
              Questionnaire::Question.new(20,23,"Ich komme besser mit Erwachsenen aus als mit Gleichaltrigen",values)
          ])  ,
          Questionnaire::QuestionGroup.new(5,5,"Prosoziales Verhalten",[
              Questionnaire::Question.new(21,1,"Ich versuche, nett zu anderen Menschen zu sein, ihre Gefühle sind mir wichtig",values),
              Questionnaire::Question.new(22,4,"Ich teile normalerweise mit Anderen (z. B. Süssigkeiten, Spielzeug, Buntstifte)",values),
              Questionnaire::Question.new(23,9,"Ich bin hilfsbereit, wenn andere verletzt, krank oder traurig sind",values),
              Questionnaire::Question.new(24,17,"Ich bin nett zu jüngeren Kindern",values),
              Questionnaire::Question.new(25,20,"Ich helfe anderen oft freiwillig (Eltern, Lehrern oder Gleichaltrigen )",values)
          ])
      ]
    end


    # @return Array[Questionnaire::Analysis]
    def analyses
      analyses=[]
      # Gesamtproblemwert
      all_questions_regarding_problems = questionnaire_results.select{|r| [1,2,3,4].include?(r.group_id) }
      filled_questions_regarding_problems = all_questions_regarding_problems.select{|r| r.result.present?}
      if filled_questions_regarding_problems.size == all_questions_regarding_problems.size # >= 12
        scaleing = (all_questions_regarding_problems.size.to_f / filled_questions_regarding_problems.size.to_f)
        value = filled_questions_regarding_problems.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(1,1,"Gesamtproblemwert",value, left_maximum: 16, right_minimum: 20)
      end

      # Einzelne Bereiche
      all_questions_group_1 = questionnaire_results.select{|r| r.group_id == 1 }
      filled_questions_group_1 = all_questions_group_1.select{|r| r.result.present?}
      if filled_questions_group_1.size == all_questions_group_1.size # >= 4
        scaleing = (all_questions_group_1.size.to_f / filled_questions_group_1.size.to_f)
        value = filled_questions_group_1.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(2,2,"Emotionale Probleme",value, left_maximum: 6, right_minimum: 7)
      end
      all_questions_group_2 = questionnaire_results.select{|r| r.group_id == 2 }
      filled_questions_group_2 = all_questions_group_2.select{|r| r.result.present?}
      if filled_questions_group_2.size == all_questions_group_2.size #  >= 4
        scaleing = (all_questions_group_2.size.to_f / filled_questions_group_2.size.to_f)
        value = filled_questions_group_2.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(3,3,"Verhaltensprobleme",value, left_maximum: 4, right_minimum: 5)
      end
      all_questions_group_3 = questionnaire_results.select{|r| r.group_id == 3 }
      filled_questions_group_3 = all_questions_group_3.select{|r| r.result.present?}
      if filled_questions_group_3.size == all_questions_group_3 # >= 4
        scaleing = (all_questions_group_3.size.to_f / filled_questions_group_3.size.to_f)
        value = filled_questions_group_3.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(4,4,"Hyperaktivität",value, left_maximum: 6, right_minimum: 7)
      end
      all_questions_group_4 = questionnaire_results.select{|r| r.group_id == 4 }
      filled_questions_group_4 = all_questions_group_4.select{|r| r.result.present?}
      if filled_questions_group_4.size == all_questions_group_4.size # >= 4
        scaleing = (all_questions_group_4.size.to_f / filled_questions_group_4.size.to_f)
        value = filled_questions_group_4.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryProblemAnalysis.new(5,5,"Verhaltensprobleme mit Gleichaltrigen",value, left_maximum: 4, right_minimum: 6)
      end
      all_questions_group_5 = questionnaire_results.select{|r| r.group_id == 5 }
      filled_questions_group_5 = all_questions_group_5.select{|r| r.result.present?}
      if filled_questions_group_5.size == all_questions_group_5.size # >= 4
        scaleing = (all_questions_group_5.size.to_f / filled_questions_group_5.size.to_f)
        value = filled_questions_group_5.map(&:result).reduce(&:+) * scaleing
        analyses <<   Questionnaire::TernaryStrengthAnalysis.new(6,6,"Prosoziales Verhalten",value, left_maximum: 5, right_minimum: 10)
      end
      analyses
    end



  end
end
