module SystemTasks
  class ClassDiagnosticResultIncomplete < Base

    def _escalations
      [
          {
              Escalator::SendUserMessage => [target.portfolio_item.author,target.portfolio_item.editor]
          },
          {
              Escalator::SendUserMessage => target.portfolio_item.involved_teachers.all.to_a,
              Escalator::SendEmail => [target.portfolio_item.author,target.portfolio_item.editor]
          }
      ]
    end

    def is_manual_confirmable?
      false
    end


    class << self
      def subscribe_to
        [
            {
                klass: 'portfolio/item_class_diagnostic',
                callback: 'before_save',
                handler: 'portfolio_item_class_diagnostic_before_save'
            },
            {
                klass: 'portfolio/item_class_diagnostic',
                callback: 'after_destroy',
                handler: 'portfolio_item_class_diagnostic_after_destroy'
            }
        ]
      end

      def portfolio_item_class_diagnostic_before_save(portfolio_item_class_diagnostic)
        if portfolio_item_class_diagnostic.results_closed
          where(target: portfolio_item_class_diagnostic).delete_all
        else
          create({
             target: portfolio_item_class_diagnostic,
             client: (portfolio_item_class_diagnostic.portfolio.subject.is_a? Client) ? portfolio_item_class_diagnostic.portfolio.subject : nil,
             institution: (portfolio_item_class_diagnostic.portfolio.subject.is_a? ClientGroup) ? portfolio_item_class_diagnostic.portfolio.subject_proxy.institution : nil,
             label: portfolio_item_class_diagnostic.portfolio.subject_proxy.name,
             title:  "Die Diagnostik #{portfolio_item_class_diagnostic.diagnostic.title} für #{portfolio_item_class_diagnostic.portfolio.subject_proxy.name} muss noch eingetragen werden.",
             message: "Der Eintrag #{portfolio_item_class_diagnostic.portfolio_item.portfolio_step.name} vom  #{::I18n.localize(portfolio_item_class_diagnostic.portfolio_item.start,format: :short)} für #{portfolio_item_class_diagnostic.portfolio.subject_proxy.name} hat noch offene Diagnostiken.",
             start_at: portfolio_item_class_diagnostic.begin,
             due_at: portfolio_item_class_diagnostic.begin,
             next_escalation: portfolio_item_class_diagnostic.begin,
             escalation_delay: 86400 * 7,
             resolve_location: Rails.application.routes.url_helpers.edit_portfolio_item_path(portfolio_item_class_diagnostic.portfolio_item)
         })

        end
      end

      def portfolio_item_class_diagnostic_after_destroy(portfolio_item_class_diagnostic)
        where(target: portfolio_item_class_diagnostic).delete_all
      end

    end
  end
end