module SystemTasks
  class ClientExpertiseInspector < Base


    def _escalations
      [
          {
              Escalator::SendUserMessage => [
                  target.expertise_manager,
                  target.expertise_school_inspector,
                  target.teacher,
                  target.client_group.try(&:teacher),
                  target.expertise_teacher
              ]
          }
      ]
    end


    def is_manual_confirmable?
      true
    end

    class << self
      def subscribe_to
        [
            {
                klass: 'client',
                callback: 'after_save',
                handler: 'client_after_save'
            }
        ]
      end


      def client_after_save(client)
        if client.expertise_school_inspector_id_changed?
          where(target: client).delete_all
          if client.expertise_school_inspector_id.present?
            create({
                 target: client,
                 client: client,
                 institution: nil,
                 label: client.full_name,
                 title:  "Für das Gutachten für #{client.first_name} #{client.last_name} wurde der Schulrat bestimmt.",
                 message: "#{client.expertise_school_inspector.full_name} wurde als Schulrat bestimmt. Es soll nun eine Einrichtung gewählt werden, die das Gutachten durchführen soll.",
                 start_at: DateTime.now,
                 due_at: DateTime.now,
                 next_escalation: DateTime.now,
                 escalation_delay: 0,
                 resolve_location: Rails.application.routes.url_helpers.dashboard_client_path(client)
             })
          end
        end
      end
    end




  end
end