class UserMessage < ActiveRecord::Base

  belongs_to :recipient, polymorphic: true # this can be a user (teacher,manager)

  belongs_to :sender, polymorphic: true # this can be a user (teacher,manager) or is null when system message
  belongs_to :system_task, class_name: 'SystemTasks::Base'

  validates :recipient, presence: true

  TYPE_OUT = 0
  TYPE_OUT_NAME = "Ausgang"
  TYPE_IN = 1
  TYPE_IN_NAME = "Eingang"
  TYPES = [TYPE_OUT_NAME,TYPE_IN_NAME]
  validates :message_type, inclusion: {in:[TYPE_OUT,TYPE_IN]}
  attr_readonly :message_type

  BOX_NEW = 0
  BOX_NEW_NAME = "neu"
  BOX_READ = 1
  BOX_READ_NAME = "gelesen"
  BOX_DELETED = 2
  BOX_DELETED_NAME = "gelöscht"
  BOXES = [BOX_NEW_NAME,BOX_READ_NAME,BOX_DELETED_NAME]
  validates :message_box, absence: true, on: :create
  validates :message_box, inclusion: {in:[BOX_NEW,BOX_READ,BOX_DELETED], allow_nil: true}
  validates :message_box, presence: true, on: :update
  before_create { self.message_box=BOX_NEW }

  def read_message
    if self.message_box == BOX_NEW
      self.message_box = BOX_READ
    end
  end

  def trash_message
    self.message_box = BOX_DELETED
  end

  def restore_message
    self.message_box = BOX_READ
  end

  PRIO_LOW = 0
  PRIO_LOW_NAME = "gering"
  PRIO_MED = 1
  PRIO_MED_NAME = "mittel"
  PRIO_HI = 2
  PRIO_HI_NAME = "hoch"
  PRIOS = [PRIO_LOW_NAME,PRIO_MED_NAME,PRIO_HI_NAME]
  validates :prio, inclusion: {in:[PRIO_LOW,PRIO_MED,PRIO_HI]}

  validates :subject_text, presence: true
  validates :content, presence: true

  after_create do
    if message_type == TYPE_IN && !sender.nil?
      UserMessage.create(attributes.tap{|message| message[:message_type] = TYPE_OUT;  message[:message_box] = nil; message[:id] = nil})
    end
  end


end
