module Portfolio
  class InvolvementValidator  < ItemValidator

      attr_accessor :type

      def initialize
        # types: supporter, guardian, teacher, special_ed, class_teacher, management
        self.type = 'teacher'
      end


      def match?(item)
        case self.type
          when 'supporter'
            return item.portfolio_item_involved_supporters.reject(&:marked_for_destruction?).any?
          when 'guardian'
            return item.portfolio_item_involved_guardians.reject(&:marked_for_destruction?).any?
          when 'teacher'
            return item.portfolio_item_involved_teachers.reject(&:marked_for_destruction?).any?
          when 'special_ed'
            return item.portfolio_item_involved_teachers.reject(&:marked_for_destruction?).each do |it|
              it.set_flags
              return true if it.special_ed == true
            end
            return false
          when 'class_teacher'
            item.portfolio_item_involved_teachers.reject(&:marked_for_destruction?).each do |it|
              it.set_flags
              return true if it.class_teacher == true
            end
            return false
          when 'management'
            item.portfolio_item_involved_teachers.reject(&:marked_for_destruction?).each do |it|
              it.set_flags
              return true if it.management == true
            end
            return false
          when 'client'
            return true if item.subject_involved?
          when 'client_group'
            return true if item.subject_involved?
        end
        return true # unknown are always match
      end

      def requirement_hint
        case self.type
          when 'supporter'
            return "Ein externer muss beteiligt sein"
          when 'guardian'
            return "Ein Sorgeberechtigter muss beteiligt sein"
          when 'teacher'
            return "Ein Lehrer muss beteiligt sein"
          when 'special_ed'
            return "Ein Sonderpädagoge muss beteiligt sein"
          when 'class_teacher'
            return "Der Klassenlehrer muss beteiligt sein"
          when 'management'
            return "Die Leitung muss beteiligt sein"
          when 'client'
            return "Der Schüler muss beteiligt sein"
          when 'client_group'
            return "Die Klasse muss beteiligt sein"
        end
      end

    end
end
