class RefactorDiagnostics < ActiveRecord::Migration
  def change
    drop_table :diag_norm_scales do |t|
      t.string :name
      t.float :range_from
      t.float :range_to
      t.timestamps null: false
    end
    drop_table :diag_norm_scale_diagnostics do |t|
      t.belongs_to :diag_norm_scale
      t.belongs_to :diagnostic
      t.float :cut_off_low
      t.float :cut_off_sub_avg
      t.float :cut_off_above_avg
      t.float :cut_off_high
      t.timestamps null: false
    end
    drop_table :diag_characteristics do |t|
      t.string :name
      t.timestamps null: false
    end
    drop_table :diagnostic_diag_characteristics do |t|
      t.belongs_to :diag_characteristic
      t.belongs_to :diagnostic
      t.boolean :is_positive
      t.timestamps null: false
    end
    drop_table :diag_ranges do |t|
      t.string :name
      t.timestamps null: false
    end
    drop_table :diagnostic_diag_ranges do |t|
      t.belongs_to :diag_range
      t.belongs_to :diagnostic
      t.timestamps null: false
    end
    drop_table :diagnostics do |t|
      t.string :name
      t.string :abbreviation
      t.integer :min_level
      t.integer :max_level
      t.timestamps null: false
    end
    drop_table :portfolio_item_diagnostic_results do |t|
      t.belongs_to :portfolio_item_diagnostic
      t.belongs_to :diag_characteristic
      t.belongs_to :diag_norm_scale
      t.float :raw_result
      t.float :scaled_result
    end
    drop_table :portfolio_item_diagnostics do |t|
      t.belongs_to :portfolio_item
      t.belongs_to :diagnostic
      t.date :begin
      t.text :content
      t.timestamps null: false
    end

    create_table :diagnostics do |t|
      t.string :catalog_id, null: false
      t.string :title, null: false, index: true
      t.string :authors
      t.string :year
      t.string :subtitle
      t.string :abbreviation
      t.integer :min_level
      t.integer :max_level
      t.text :short_description
      t.text :description
      t.string :url
      t.boolean :is_range_okologie, null: false
      t.boolean :is_range_integration, null: false
      t.boolean :is_range_intensitat, null: false
      t.timestamps null: false
    end

    create_table :diagnostic_imgs do |t|
      t.string :name, null: false # large, thumb
      t.string :diagnostic_id, null: false
      t.integer :width_px, null: false
      t.integer :height_px, null: false
      t.timestamps null: false
    end

    create_table :characteristics do |t|
      t.string :name
      t.boolean :is_positive
      t.belongs_to :diagnostic
      t.timestamps null: false
    end

    create_table :norm_scales do |t|
      t.string :name
      t.float :range_from
      t.float :range_to
      t.float :std_dev
      t.float :avg
      t.float :cut_off_low
      t.float :cut_off_sub_avg
      t.float :cut_off_above_avg
      t.float :cut_off_high
      t.string :catalog_fields
      t.belongs_to :diagnostic
      t.timestamps null: false
    end


    create_table :portfolio_item_diagnostic_results do |t|
      t.belongs_to :portfolio_item_diagnostic
      t.belongs_to :characteristic
      t.belongs_to :norm_scale
      t.float :raw_result
      t.float :scaled_result
      t.timestamps null: false
    end


    create_table :portfolio_item_diagnostics do |t|
      t.belongs_to :portfolio_item
      t.belongs_to :diagnostic
      t.date :begin
      t.text :content
      t.timestamps null: false
    end

  end



end
