class CreateEducationalCourseTables < ActiveRecord::Migration
  def change
    # Bildungsgänge (z.B. Grundschule, Gymnasium, Gesamtschule, Gymnasiale Oberstufe)
    # refs #217
    create_table :educational_courses do |t|
      t.string :name
      t.date :valid_from # inkrafttreten der gesetzlichen Grundlage. Erfordert auch einen neuen satz an regeln.
      # Klassen die regeln aus alten Bildungsgängen haben, können über course_stage_name weiterhin
      # berücksichtigt werden.
    end


    # Abschnitte der Bildungsgänge (z.B. Primarstufe, Schuleingangsphase, Erprobungsstufe)
    # refs #217
    create_table :educational_course_rules do |t|
      t.string :course_stage_name # Kürzel für den Abschnitt. Alle Klassen mit diesem Kürzel werden bei der Regel berücksichtigt
      t.string :name # informativ
      t.integer :min_duration_years # Verweildauer des Schülers in Klassen mit dem gegebenen course_stage_name darf min_duration_years nicht unterschreiten
      t.integer :max_duration_years # Verweildauer des Schülers in Klassen mit dem gegebenen course_stage_name darf max_duration_years nicht überschreiten
      t.references :educational_course
      t.timestamps
    end

    create_table :educational_courses_institutions, :id => false do |t|
      t.references :educational_course
      t.references :institution
    end

    # Das Kürzel für die Phase sollte für einen Bildungsgang eindeutig sein.
    add_index(:educational_course_rules, [:course_stage_name, :educational_course_id], unique: true, name: 'idx_ecr_on_csn_and_ec_id')

  end
end
