class Feature430 < ActiveRecord::Migration
  def up

    # TEMPLATE TABLES

    create_table :checklist_tpls do |t|
      t.string :name, null: false
      t.string :checklist_type, null: false
      t.references :portfolio_specialization, null: true, index: true
      t.boolean :is_active, null: false, default: true
    end
    add_foreign_key :checklist_tpls, :portfolio_specializations, on_delete: :nullify

    execute <<-SQL
      INSERT INTO checklist_tpls ("name",checklist_type,portfolio_specialization_id,is_active) VALUES ('Checkliste zur Antragstellung AO-SF','Antrag_AOSF',NULL,true) -- pk: 1
    SQL

    create_table :checklist_group_tpls do |t|
      t.references :checklist_tpl, null: false, index: true
      t.references :portfolio_specialization, null: true, index: true
      t.boolean :is_mandatory, null: false, default: false
      t.string :name, null: false
    end
    add_foreign_key :checklist_group_tpls, :checklist_tpls, on_delete: :cascade
    add_foreign_key :checklist_group_tpls, :portfolio_specializations, on_delete: :nullify

    execute <<-SQL
      INSERT INTO checklist_group_tpls ("name",checklist_tpl_id,portfolio_specialization_id,is_mandatory) VALUES
      --('Formale Anforderungen',1,NULL,true), -- pk: 1
      ('Inhaltliche Anforderungen vermuteter Förderschwerpunkt Lernen',1,NULL,false), -- pk: 1
      ('Inhaltliche Anforderungen vermuteter Förderschwerpunkt Sprache',1,NULL,false), -- pk: 2
      ('Inhaltliche Anforderungen vermuteter Förderschwerpunkt Emotionale u. soziale Entwicklung',1,NULL,false), -- pk: 3
      ('Weitere Unterlagen zum Antrag',1,NULL,true), -- pk: 4
      ('Unterlagen zu Anträgen für Kinder, die zum nächsten Schuljahr schulpflichtig werden.',1,NULL,false) -- pk: 5
    SQL

    create_table :checklist_question_tpls do |t|
      t.string :name, null: false
      t.references :checklist_tpl, null: false, index: true
      t.references :checklist_group_tpl, null: false, index: true
      t.references :portfolio_specialization, null: true, index: true
      t.boolean :is_checkable, null: false # the user can explicitly check this item. In this case the Item is checked, no matter if any of the other options is added.
      t.boolean :has_freetext, null: false # the user can add a custom freetext to the item. When a text is added, the item is considered as checked.
      t.boolean :has_portfolio_item_references, null: false # the user can add references to portfolio items. When a reference exists, the item is considered as checked.
      t.boolean :is_mandatory, null: false, default: false # wether the item is mandatory
      t.boolean :accepts_upload, null: false, default: false # the user can attach a document to the item.
    end
    add_foreign_key :checklist_question_tpls, :checklist_tpls
    add_foreign_key :checklist_question_tpls, :checklist_group_tpls, on_delete: :cascade
    add_foreign_key :checklist_question_tpls, :portfolio_specializations, on_delete: :nullify

    execute <<-SQL
      INSERT INTO checklist_question_tpls ("name",checklist_tpl_id,checklist_group_tpl_id,portfolio_specialization_id,
      is_checkable,
      has_freetext,
      has_portfolio_item_references,
      is_mandatory,
      accepts_upload) VALUES
      --('aktuelles AO-SF Formular',1,1,NULL,
      --false,false,true,true,true),
      --('Angaben zum Schulbesuchsjahr',1,1,NULL,
      --false,true,false,true,false),
      --('Unterschriften der Erziehungsberechtigten',1,1,NULL,
      --false,false,true,true,true),
      --('Unterschrift Schulleitung',1,1,NULL,
      --false,false,true,true,true),
      --('Bescheid des Schulamtes ( bei Antrag auf Förderortwechsel bzw. Wechsel des Förderschwerpunktes )',1,1,NULL,
      --false,false,true,false,true),

      ('Aussagen zur Lern- und Leistungsentwicklung in allen Fächern bezogen auf die Kompetenzerwartungen mit Schwerpunktsetzung auf den vermuteten Förderschwerpunkt',1,1,NULL,
      false,true,true,true,false),
      ('Aussagen zum Arbeits- und Sozialverhalten in allen Fächern',1,1,NULL,
      false,true,true,true,false),
      ('Beobachtungen zu Lernstrategien, Selbstständigkeit, Ausdauer, Belastbarkeit',1,1,NULL,
      false,true,true,true,false),
      ('Aussagen zu besonderen pädagogischen Bedürfnissen',1,1,NULL,
      false,true,true,true,false),
      ('Zusammenfassung im Hinblick auf den vermuteten Förderschwerpunkt LE',1,1,NULL,
      false,true,true,true,false),

      ('Allgemeine Lern- und Leistungsentwicklung in den Fächern D, M, SU, E, ggfs. weitere Fächer',1,2,NULL,
      false,true,true,true,false),
      ('Aussagen zu Arbeits- und Sozialverhalten in den Fächern',1,2,NULL,
      false,true,true,true,false),
      ('Erzählverhalten - Auffälligkeiten',1,2,NULL,
      false,true,true,true,false),
      ('Beobachtungen zu Begriffsbildung und Wortschatzentwicklung',1,2,NULL,
      false,true,true,true,false),
      ('Auffälligkeiten in Satzbau und Grammatik',1,2,NULL,
      false,true,true,true,false),
      ('Auffälligkeiten im Bereich der Artikulation',1,2,NULL,
      false,true,true,true,false),
      ('Aussagen zum Sprachverständnis bzw. Störung der Semantik',1,2,NULL,
      false,true,true,true,false),
      ('Aussagen zur individuellen Förderung im Bereich Sprache',1,2,NULL,
      false,true,true,true,false),
      ('Auswirkungen auf schulisches Lernen, z.B. Schriftspracherwerb',1,2,NULL,
      false,true,true,true,false),
      ('Ergebnisse angewandter Testverfahren von Ärzten und außerschulischen Instituten',1,2,NULL,
      false,true,true,true,false),
      ('außerschulische Förderung',1,2,NULL,
      false,true,true,true,false),
      ('Zusammenfassung im Hinblick auf den vermuteten Förderbedarf SQ',1,2,NULL,
      false,true,true,true,false),

      ('Allgemeine Lern- und Leistungsentwicklung in den Fächern D, M, SU, E, ggfs. weitere Fächer',1,3,NULL,
      false,true,true,true,false),
      ('Aussagen zum Arbeits- und Sozialverhalten in allen Fächern, insbesondere in Einzelarbeit, Partnerarbeit und Gruppensituationen',1,3,NULL,
      false,true,true,true,false),
      ('Verhalten in der Klasse, Rolle in der Klasse',1,3,NULL,
      false,true,true,true,false),
      ('Verhalten in gebundenen Situationen',1,3,NULL,
      false,true,true,true,false),
      ('Verhalten in offenen Situationen wie Pause, Spiel, Sport, offenen Unterrichtsformen',1,3,NULL,
      false,true,true,true,false),
      ('Konfliktverhalten, Konfliktstrategien',1,3,NULL,
      false,true,true,true,false),
      ('Darstellung von Ordnungsmassnahmen',1,3,NULL,
      false,true,true,true,false),
      --('Ausgewertete Ergebnisse des SDQ (oder ggfs. LSL)',1,3,NULL,
      --false,true,true,true,true),
      ('Auswirkungen auf das Lern- und Arbeitsverhalten',1,3,NULL,
      false,true,true,true,false),
      ('Zusammenfassung im Hinblick auf den vermuteten Förderschwerpunkt ES',1,3,NULL,
      false,true,true,true,false),


      ('Erläuterungen zum bisherigen schulischen Bildungsweg',1,4,NULL,
      false,true,false,true,true),
      ('Darstellung, dass die schulischen Möglichkeiten zur Förderung ausgeschöpft sind',1,4,NULL,
      false,true,true,true,true),
      ('Dokumentation der Gespräche und der Beratung mit den Sorgeberechtigten, inkl. Elternwusch zur Beschulung',1,4,NULL,
      false,false,true,true,true),
      --('aktuelles und evaluiertes Lern- und Förderportfolio',1,4,NULL,
      --false,false,true,true,false),
      --('ggfs. aktueller und evaluierter sonderpädagogischer Förderplan',1,4,NULL,
      --false,false,true,false,false),
      ('Dokumentation der bisherigen Förderung',1,4,NULL,
      true,true,true,true,false),
      ('Dokumentation außerschulischer Förderung',1,4,NULL,
      true,true,true,true,true),
      ('Aktuelle Zeugnisse',1,4,NULL,
      true,false,false,true,true),
      ('Protokolle der Konferenzen, die sich mit dem/der Schüler/in befasst haben',1,4,NULL,
      false,false,true,false,true),
      ('Schulleistungsdiagnostik (wie z.B. HSP)',1,4,NULL,
      false,false,true,false,true),
      ('Dokumentation der kollegialen fallbezogenen Beratung',1,4,NULL,
      false,false,true,false,true),
      ('Dokumentation Kontakt zu außerschulischen Einrichtungen (schulpsychologischer Dienst, Jugendhilfe, ...)',1,4,NULL,
      false,false,true,false,true),
      ('Ergebnisse von Untersuchungen, falls Eltern diese zur Verfügung stellen',1,4,NULL,
      false,false,true,false,true),

      ('Darstellung der vorschulischen Förderung',1,5,NULL,
      false,true,false,true,true),
      ('Ergebnisse der Schuleingangsdiagnostik',1,5,NULL,
      false,true,false,true,true),
      ('Bildungsdokumentation, falls diese Vorliegt',1,5,NULL,
      false,true,false,false,true),
      ('Ergebnisse der Einschulungsuntersuchung',1,5,NULL,
      false,true,false,true,true)
    SQL

    # DATA TABLES

    create_table :checklists do |t|
      t.references :checklist_tpl, null: true, index: true
      t.references :portfolio_item, null: true, index: true
      t.references :teacher, null: true, index: true
      t.references :manager, null: true, index: true
      t.string :name, null: false
      t.string :checklist_type
      t.references :portfolio_specialization, null: true, index: true
    end
    add_foreign_key :checklists, :checklist_tpls, on_delete: :nullify
    add_foreign_key :checklists, :teachers, on_delete: :nullify
    add_foreign_key :checklists, :managers, on_delete: :nullify
    add_foreign_key :checklists, :portfolio_items, on_delete: :cascade
    add_foreign_key :checklists, :portfolio_specializations, on_delete: :nullify

    create_table :checklist_groups do |t|
      t.references :checklist, null: false, index: true
      t.string :name, null: false
      t.boolean :is_mandatory, null: false, default: false
      t.references :portfolio_specialization, null: true, index: true
    end
    add_foreign_key :checklist_groups, :checklists, on_delete: :cascade

    create_table :checklist_questions do |t|
      t.string :name, null: false
      t.references :checklist, null: false, index: true
      t.references :portfolio_specialization, null: true, index: true
      t.references :checklist_group, null: true, index: true
      t.boolean :is_checkable, null: false
      t.boolean :has_freetext, null: false
      t.boolean :has_portfolio_item_references, null: false
      t.boolean :accepts_upload, null: false
      t.boolean :is_checked, null: true
      t.boolean :is_mandatory, null: false
      t.string :file, null: true
      t.string :freetext, null: true
    end
    add_foreign_key :checklist_questions, :checklists, on_delete: :cascade
    add_foreign_key :checklist_questions, :portfolio_specializations, on_delete: :nullify
    add_foreign_key :checklist_questions, :checklist_groups, on_delete: :cascade

    create_table :checklist_questions_portfolio_items, id: false do |t|
      t.references :checklist_question, null: false, index: { name: 'idx_cqpi_on_cq'}
      t.references :portfolio_item, null: true, index: { name: 'idx_cqpi_on_pi'}
    end
    add_foreign_key :checklist_questions_portfolio_items, :checklist_questions, on_delete: :cascade
    add_foreign_key :checklist_questions_portfolio_items, :portfolio_items, on_delete: :cascade

  end

  def down
    drop_table :checklist_questions_portfolio_items
    drop_table :checklist_questions
    drop_table :checklist_groups
    drop_table :checklists
    drop_table :checklist_question_tpls
    drop_table :checklist_group_tpls
    drop_table :checklist_tpls
  end
end
