module CoreExtensions
  module String
    module Similarity

      # Detect name similarities ( german phonetics) using
      # koelner phonetic
      # Damerau-Levenshtein ( for typos that do not already sound similar)
      # Compares parts of names, discarding later parts from the string with more parts.
      #
      # levensthein distance, normalizer and splitter can be passed
      # lsd: maximum distance for match (distance is roughly the number of typos expected)
      # normalizer: substitues via regex with empty string before matching
      # splitter: how to split strings for part name comparison
      def similar?(s_compare, lsd = 1, normalizer= /[\\'\.\s-]+/, splitter = /[\\'\s-]+/)
        return true if empty? && s_compare.empty?
        return false if empty? && !s_compare.empty? || !empty? && s_compare.empty?
        first = strip.gsub(normalizer, '').downcase
        second = s_compare.strip.gsub(normalizer, '').downcase
        return true if first.phonetic_code == second.phonetic_code
        return true if Levenshtein.distance(first, second) <= lsd
        ary_0 = strip.split(splitter)
        ary_1 = s_compare.strip.split(splitter)
        if [ary_0.length,ary_1.length].max > 1
          res = true
          0.upto([ary_0.length,ary_1.length].min - 1) do |i|
            ary_0_normed = ary_0[i].gsub(normalizer, '').downcase
            ary_1_normed = ary_1[i].gsub(normalizer, '').downcase
            if ary_0_normed.phonetic_code == ary_1_normed.phonetic_code
              res = res && true
            else
              res = res && (Levenshtein.distance(ary_0_normed, ary_1_normed) <= lsd)
            end
          end
          return res
        end
        return false
      end

    end
  end
end
