#!/bin/bash
#-----------------------------------------------------------------------------------------------------------------------
#
# This is the start script for the application server
# The server will start in foreground, it is adviseable to put this script into init / systemd
# so, a respawn / restart directive can be applied
#
# USAGE: srvctl.sh { start | stop | restart } { production | development }
#
#-----------------------------------------------------------------------------------------------------------------------

INSTANZ="Vschoolboard Application Server"
SCRIPT=$(readlink -f "$0")
SCRIPTPATH=$(dirname "$SCRIPT")
APP_ENVIRONMENT="$2"
cd $SCRIPTPATH
Pidfile=tmp/pids/puma.pid

if [ -f $Pidfile ]
then
	Pid=`cat $Pidfile`
fi

case "$1" in
'start')
		if [ -f $Pidfile ] ; then
				if test `ps -e | grep -c $Pid` = 1; then
						echo "Not starting $INSTANZ - instance already running with PID: $Pid"
						exit 1
				else
						echo "Starting $INSTANZ"
						rm "$Pidfile"
						bundle exec puma -C "config/puma/$2.rb"
						exit $?
				fi
		else
				echo "Starting $INSTANZ"
				bundle exec puma -C "config/puma/$2.rb"
				exit $?
		fi
		;;

'stop')
		if [ -f $Pidfile ] ; then
				echo "stopping $INSTANZ"
				bundle exec pumactl -P $Pidfile stop
				e_stat=$?
				rm "$Pidfile"
				exit $e_stat
		else
				echo "Cannot stop $INSTANZ - no Pidfile found!"
				exit 1
		fi
		;;

'restart')
    echo "restarting $INSTANZ"
    if [[ -n "$Pid" ]]; then
      if ps -p "$Pid"; then
        bundle exec pumactl -P "$Pidfile" restart
        exit $?
      else
        rm "$Pidfile"
        echo "server not running, cannot restart"
        exit 1
      fi
    else
      rm "$Pidfile"
      echo "server not running, cannot restart"
      exit 1
    fi
		;;

*)
		echo "usage: $0 { start | stop | restart } { production | development }"
		;;

esac
exit 1